@@ -1,6 +1,15 @@
 import React, { useState, useContext } from "react";
 import { Link, useParams } from "react-router-dom";
-import { TLink, SLink, useData, version, Save, Delete, CopyText } from "./Util";
+import {
+  TLink,
+  SLink,
+  useData,
+  version,
+  Save,
+  Delete,
+  CopyText,
+  HasActionIcon,
+} from "./Util";
 import { Results } from "./Results";
 import { getPartsForQuery, getRelUrlForQuery } from "./Query";
 import { ShowTooltip, HideTooltip } from "./Tooltip";
@@ -161,7 +170,7 @@ function Filter(props) {
 function Filters(props) {
   const { query, filterErrors, parsedFilterValues } = props;
   return (
-    <form className="Filters">
+    <form className="Filters" onSubmit={(e) => e.preventDefault()}>
       <table>
         <tbody>
           {props.filters.map((filter, index) => (
@@ -216,6 +225,10 @@ function Field(props) {
               }
             >
               {modelField.prettyName}
+              <HasActionIcon
+                modelField={modelField}
+                message="Has admin actions."
+              />
             </TLink>
           ) : (
             modelField.prettyName + (modelField.toMany ? " \u21f6" : "")
@@ -442,7 +455,7 @@ function EditSavedView(props) {
         </form>
         <div className="SavedViewActions">
           <Delete apiUrl={url} redirectUrl="/" />
-          <Link to="/">Done</Link>
+          <Link to="/">Close</Link>
         </div>
       </div>
     </div>
